# UPON REQUEST OF CRAN, THIS R PACKAGE WAS RENAMED TO `cleaner` AND CONSEQUENTLY THIS PROJECT HAS MOVED TO A NEW LOCATION: https://www.github.com/msberends/cleaner

**Website of this package: https://msberends.github.io/cleaner**

