\name{call.treeview}
\alias{call.treeview}
\title{Function to call the standalone fTreeView Java application}
\description{
    This function calls fTreeview, a Java appplication to display the heatmap, gene clustering, sample clustering, and functional annotation files generated with the CLEAN package.
}
\usage{
call.treeview(cdtFile = "cluster.cdt", treeViewPath = .fTreeViewPath, wait = FALSE)
}
\arguments{
  \item{cdtFile}{A file in cdt format.  The .cdt file name extension may be omitted}
  \item{treeViewPath}{Path where the treeview jar file is located}
  \item{wait}{Parameter to the system() function}
}
\author{Johannes Freudenberg}
\seealso{\code{\link{funcClustAnnot}}, \code{\link{system}}, \code{\link{r2cdt}}}
\examples{
## not run
# data(gimmOut)
# funcClustAnnot(gimmOut, file = "cluster")
# call.treeview("cluster.cdt")
}
\keyword{ IO }
\keyword{ cluster }

