\name{gimmOut}
\alias{gimmOut}
\docType{data}
\title{An gimmR object, i.e. a list containing a dataframe with gene expression data, and two hclust objects representing the gene clustering and sample clustering, respectively.}
\description{
  The data set contains log-fold changes for 94 genes in 46 samples under 9 different treatments.  The complete data set (11,498 genes) can be downloaded from the Gene Expression Omnibus (http://www.ncbi.nlm.nih.gov/sites/entrez?db=gds, accession GSE14933)
}
\usage{data(gimmOut)}
\format{
}
\details{
}
\source{
See http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE14933 for details.
}
\references{
http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE14933
Medvedovic et al. Influence of fatty acid diets on gene expression in rat mammary epithelial cells. 2009. Physiol Genomics 38(1):80-8.
}
\examples{
## not run
data(gimmOut)
require(CLEAN.Rn)
runCLEAN(gimmOut, species = "Rn")
}
\keyword{datasets}
